@@ -58,8 +58,7 @@ sub main {
     my $view = Args::get_view();
 
     if ($view == $Appsort::BLANK) {
-        blank();	
-        return 0;
+        return blank();
     }
 
     # Check Basic Args
@@ -363,10 +362,16 @@ sub run {
 
 # Blank Page
 sub blank { 
-    Print::print_html_header("");
-    print "<!-- This Page Intentionally Left Blank -->\n";
+	Print::print_html_header("");
+	print "<center><h3>File Type Sorting</h3>\n".
+	  "In this mode, Autopsy will examine allocated and unallocated files<br> and ".
+	  "sort them into categories and verify the extension.<p>This allows you to find a file based on".
+	  "its type and find \"hidden\" files.<p>\n".
+
+	  "WARNING: This can be a time intensive process.<br>\n";
+
 	Print::print_html_footer();
-    return 0;
+	return 0;
 };
 
 
