@@ -75,7 +75,8 @@ my $IMG_MAX = 20;
 # %img2mnt;   # Mapping for mount point, given the image name
 # %img2ftype; # Mapping for file system type, given the image name
 # %mod2img;   # Mapping for image, given the strings or dls
-# %img2str;   # Mapping for strings file, given  the image name
+# %img2str;   # Mapping for ASCII strings file, given  the image name
+# %img2uni;   # Mapping for Unicode strings file, given  the image name
 # %img2dls;   # Mapping for dls file, given  the image name
 
 
@@ -360,7 +361,7 @@ print <<EOF;
 <input type=\"hidden\" name=\"view\" value=\"$Caseman::CASE_NEW_DOIT\">
 <tr>
   <td colspan=3 align=left>
-    1.  <b>Case Name:</b> The name of this investigation.  It can only contain letters, numbers, and symbols.
+    1.  <b>Case Name:</b> The name of this investigation.  It can contain only letters, numbers, and symbols.
   </td>
 </tr>
 <tr>
@@ -554,7 +555,8 @@ sub case_open {
 	# Were there any cases?  
 	if (scalar @cases == 0) {
             print "<tr><td align=\"center\">".
-              "No cases exist in <tt>$::LOCKDIR</tt>".
+              "No cases exist in <tt>$::LOCKDIR</tt><br><br>\n".
+	      "Select the New Case button below to make one\n".
               "</td></tr>\n";
 	}
 	else {
@@ -738,6 +740,7 @@ sub read_host_config {
 	if ($::LIVE == 1) {
 		%Caseman::mod2img = ();
 		%Caseman::img2str = ();
+		%Caseman::img2uni = ();
 		%Caseman::img2dls = ();
 	
 		$Caseman::tz = "";
@@ -760,6 +763,7 @@ sub read_host_config {
 	%Caseman::img2ftype = ();
 	%Caseman::mod2img = ();
 	%Caseman::img2str = ();
+	%Caseman::img2uni = ();
 	%Caseman::img2dls = ();
 	
 	$Caseman::tz = "";
@@ -830,6 +834,32 @@ sub read_host_config {
 			$Caseman::mod2img{$i} = $o;
 			$Caseman::img2str{$o} = $i;
 		}
+		# entry for a strings or dls file
+		#
+		# unistrings 	data/hda1.str		images/hda1.dd
+		elsif (/^unistrings\s+($::REG_IMG)\s+($::REG_IMG)$/o) {
+			my $i = $1;
+			my $o = $2;
+
+			unless ((-e "$::host_dir$i") || 
+			  ((-l "$::host_dir$i") && (-e readlink "$::host_dir$i"))) {
+				Print::print_check_err(
+				  "Error: Unicode strings file not found: ".
+				  "$::host_dir$i<br>Edit host config in $::host_dir and refresh your browser");
+			}
+
+			unless ((-e "$::host_dir$o") || 
+			  ((-l "$::host_dir$o") && (-e readlink "$::host_dir$o"))) {
+				Print::print_check_err(
+				  "Error: Unicode strings original not found: ".
+				  "$::host_dir$o<br>Edit host config in $::host_dir and refresh your browser");
+			}
+
+			$Caseman::img2ftype{$i} = "strings";
+			$Caseman::mod2img{$i} = $o;
+			$Caseman::img2uni{$o} = $i;
+		}
+
 
 		# dls entry
 		# dls data/image.dls	[images/image.dd]
@@ -1051,7 +1081,7 @@ sub host_add {
 	  "<tr><td colspan=\"2\">&nbsp;</td></tr>".
 	
 	# Host name
-	  "<tr><td align=\"left\" colspan=2>1.  <b>Host Name:</b>  The name of the computer being investigated.  It can only have letters, numbers, and symbols.</td></tr>".
+	  "<tr><td align=\"left\" colspan=2>1.  <b>Host Name:</b>  The name of the computer being investigated.  It can contain only letters, numbers, and symbols.</td></tr>".
 	  "<tr><td align=\"left\">&nbsp;&nbsp;&nbsp;</td>".
 	  "<td align=\"left\"><input type=\"text\" name=\"host\" size=32 maxlength=32 value=\"host1\"></td></tr>\n".
 
@@ -1323,8 +1353,9 @@ sub host_open {
 
 	if (scalar @hosts == 0) {
         print "<tr><td colspan=\"4\" align=center>".
-		  "No hosts have been added to case yet".
-		  "</td></tr></table>\n";
+	  "No hosts have been added to case yet".
+	   "<br><br>Select the Add Host button below to make one.\n".
+	   "</td></tr></table>\n";
 	}
 	else {
 		print "<form action=\"$::PROGNAME\" method=\"get\">\n".
@@ -1604,7 +1635,10 @@ sub img_open {
 	# the images have been loaded from reading the host config file in
 	# autopsy_main
 	if (scalar (keys %Caseman::img2ftype) == 0) {
-		print "</table>No images have been added to this host yet<br>\n";
+		print "<tr><td align=\"center\">".
+		  "No images have been added to this host yet<br><br>\n".
+		  "Select the Add Image button below to add one\n".
+		  "</td></tr></table>\n";
 		goto EGRESS;
 	}
 
@@ -2293,13 +2327,21 @@ sub img_details {
 	  "  <tr><td colspan=\"2\">&nbsp;</td></tr>\n".
 
 	  # Strings File
-	  "  <tr><td align=\"right\"><b>Strings File:</b></td>".
+	  "  <tr><td align=\"right\"><b>ASCII Strings File:</b></td>".
 	  "<td align=\"left\"><tt>".
 	  ((exists $Caseman::img2str{$Args::args{'img'}}) ? 
 		$Caseman::img2str{$Args::args{'img'}} : "&nbsp;").
+	  "</tt></td></tr>\n".
+
+	  # Unicode Strings File
+	  "  <tr><td align=\"right\"><b>Unicode Strings File:</b></td>".
+	  "<td align=\"left\"><tt>".
+	  ((exists $Caseman::img2uni{$Args::args{'img'}}) ? 
+		$Caseman::img2uni{$Args::args{'img'}} : "&nbsp;").
 	  "</tt></td></tr>\n";
 
 
+
 	if (($ftype ne "raw") && ($ftype ne "swap")) {
 		# dls file
 		print 
@@ -2310,45 +2352,63 @@ sub img_details {
 
 		# Strings of dls
 		print 
-		  "  <tr><td align=\"right\"><b>Strings of Unallocated $Fs::addr_unit{$ftype}s File:</b></td>".
+		  "  <tr><td align=\"right\"><b>ASCII Strings of Unallocated $Fs::addr_unit{$ftype}s File:</b></td>".
 		  "<td align=\"left\"><tt>".
 		  ( ( (exists $Caseman::img2dls{$Args::args{'img'}}) &&
 		  (exists $Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}})) ? 
 			$Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}} : "&nbsp;").
 		  "</tt></td></tr>\n";
+
+		# Unicodde Strings of dls
+		print 
+		  "  <tr><td align=\"right\"><b>Unicode Strings of Unallocated $Fs::addr_unit{$ftype}s File:</b></td>".
+		  "<td align=\"left\"><tt>".
+		  ( ( (exists $Caseman::img2dls{$Args::args{'img'}}) &&
+		  (exists $Caseman::img2uni{$Caseman::img2dls{$Args::args{'img'}}})) ? 
+			$Caseman::img2uni{$Caseman::img2dls{$Args::args{'img'}}} : "&nbsp;").
+		  "</tt></td></tr>\n";
 	}
 
 	print "  <tr><td colspan=\"2\">&nbsp;</td></tr>\n".
-	  "</table>\n";
+	  "</table>\n<a name=\"extract\"\n";
 
 	# Section for Strings file and 'dls' file
 
-	if ( (!(defined $Caseman::img2str{$Args::args{'img'}})) || 
+	if ( 
+	  (!(defined $Caseman::img2str{$Args::args{'img'}})) || 
+	  (!(defined $Caseman::img2uni{$Args::args{'img'}})) || 
 	  (!(defined $Caseman::img2dls{$Args::args{'img'}})) || 
-	  ((defined $Caseman::img2dls{$Args::args{'img'}}) && 
-	   (!(defined $Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}})))) { 
+	  ( (defined $Caseman::img2dls{$Args::args{'img'}}) && 
+	   ((!(defined $Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}})) || 
+	   (!(defined $Caseman::img2uni{$Caseman::img2dls{$Args::args{'img'}}}))))) { 
 		print "<hr><table width=600>\n<tr>";
 	}
 
 	# Strings File
-	if (!(defined $Caseman::img2str{$Args::args{'img'}})) {
+	if ((!(defined $Caseman::img2str{$Args::args{'img'}})) || 
+	  (!(defined $Caseman::img2uni{$Args::args{'img'}}))) {
 
 		(my $img_dir, my $str_img) = split (/\//,$Args::args{'img'});
 
-		print "<td align=\"center\" width=280><h3>Extract ASCII Strings</h3>".
-		  "Extracting the ASCII strings from a file system image will ".
+		print "<td align=\"center\" width=280><h3>Extract Strings of<br>Entire Image</h3>".
+		  "Extracting the ASCII and Unicode strings from a file system image will ".
 		  "make keyword searching faster.<br><br>\n".
 		  "<form action=\"$::PROGNAME\" method=\"get\">\n".
-		  "File Name: <input type=\"text\" name=\"fname\" ".
-		  "value=\"$str_img.str\"><br><br>\n".
 		  "Generate MD5? ".                      
 		  "<input type=\"checkbox\" name=\"md5\" value=\"1\" CHECKED><br><br>".
                   "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_CASEMAN\">\n".
                   "<input type=\"hidden\" name=\"view\" value=\"$Caseman::IMG_MAKESTR\">\n".
 		  "<input type=\"hidden\" name=\"img\" value=\"$Args::args{'img'}\">\n".
-		  "<input type=\"hidden\" name=\"fname_mode\" value=\"$FNAME_MODE_INIT\">\n".
-		  Args::make_hidden().
-		  "<input type=\"image\" src=\"pict/srch_b_str.jpg\" ". 
+		  Args::make_hidden();
+
+		if (!(defined $Caseman::img2str{$Args::args{'img'}})) {
+		    print "ASCII: <input type=\"checkbox\" name=\"str\" value=\"1\" CHECKED>  \n";
+		}
+		if (!(defined $Caseman::img2uni{$Args::args{'img'}})) {
+		    print "  Unicode: <input type=\"checkbox\" name=\"uni\" value=\"1\" CHECKED>\n";
+		}
+
+		print "<br><br><input type=\"image\" src=\"pict/srch_b_str.jpg\" ". 
 		  "alt=\"Extract Strings\" border=\"0\">\n</form></td>\n".
 		  "<td width=40>&nbsp;</td>\n";
 	}
@@ -2363,15 +2423,8 @@ sub img_details {
 		  "Extracting the unallocated data in a file system image allows ".
 		  "more focused keyword searches and data recovery.<br><br>\n".
 		  "(Note: This Does Not Include Slack Space)<br>\n".
-		  "<form action=\"$::PROGNAME\" method=\"get\">\n".
-		  "File Name: <input type=\"text\" name=\"fname\" ";
-		
-		(my $img_dir, my $dls_img) = split (/\//,$Args::args{'img'});
-		if ($dls_img =~ /^(.*?)\.dd$/) {
-			print "value=\"$1.dls\"><br><br>\n";
-		} else {
-			print "value=\"${dls_img}.dls\"><br><br>\n";
-		}
+		  "<form action=\"$::PROGNAME\" method=\"get\">\n";
+
 
 		print "Generate MD5? ".                      
 		  "<input type=\"checkbox\" name=\"md5\" value=\"1\" CHECKED><br><br>".
@@ -2379,22 +2432,20 @@ sub img_details {
                   "<input type=\"hidden\" name=\"view\" value=\"$Caseman::IMG_MAKEDLS\">\n".
 
 		  "<input type=\"hidden\" name=\"img\" value=\"$Args::args{'img'}\">\n".
-		  "<input type=\"hidden\" name=\"fname_mode\" value=\"$FNAME_MODE_INIT\">\n".
 		  Args::make_hidden().
 		  "<input type=\"image\" src=\"pict/srch_b_un.jpg\" ". 
 		  "alt=\"Extract Unallocated Data\" border=\"0\">\n<br></form>\n";
 	}
 
 	# strings of 'dls'
-	elsif (!(defined $Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}})) { 
+	elsif ((!(defined $Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}})) ||
+	  (!(defined $Caseman::img2uni{$Caseman::img2dls{$Args::args{'img'}}})) ) { 
 		(my $img_dir, my $str_img) = split (/\//,$Caseman::img2dls{$Args::args{'img'}});
 
-		print "<td align=\"center\" width=280><h3>Extract ASCII Strings<br>of Unallocated $Fs::addr_unit{$ftype}s</h3>".
+		print "<td align=\"center\" width=280><h3>Extract Strings of<br>Unallocated $Fs::addr_unit{$ftype}s</h3>".
 		  "Extracting the ASCII strings from the unallocated data will make ".
 		  "keyword searching faster.<br><br>\n".
 		  "<form action=\"$::PROGNAME\" method=\"get\">\n".
-		  "File Name: <input type=\"text\" name=\"fname\" ".
-		  "value=\"$str_img.str\"><br><br>\n".
 		  "Generate MD5? ".                      
 		  "<input type=\"checkbox\" name=\"md5\" value=\"1\" CHECKED><br><br>".
                   "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_CASEMAN\">\n".
@@ -2402,14 +2453,24 @@ sub img_details {
 
 		  "<input type=\"hidden\" name=\"img\" value=\"$Caseman::img2dls{$Args::args{'img'}}\">\n".
 		  "<input type=\"hidden\" name=\"fname_mode\" value=\"$FNAME_MODE_INIT\">\n".
-		  Args::make_hidden().
-		  "<input type=\"image\" src=\"pict/srch_b_str.jpg\" ". 
+		  Args::make_hidden();
+
+		if (!(defined $Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}})) {
+		    print "ASCII: <input type=\"checkbox\" name=\"str\" value=\"1\" CHECKED>  \n";
+		}
+		if (!(defined $Caseman::img2uni{$Caseman::img2dls{$Args::args{'img'}}})) {
+		    print "  Unicode: <input type=\"checkbox\" name=\"uni\" value=\"1\" CHECKED>\n";
+		}
+		print "<br><br><input type=\"image\" src=\"pict/srch_b_str.jpg\" ". 
 		  "alt=\"Extract Strings\" border=\"0\">\n</form></td>\n";
 	}
-
-	if ( (!(defined $Caseman::img2str{$Args::args{'img'}})) || 
+	if ( 
+	  (!(defined $Caseman::img2str{$Args::args{'img'}})) || 
+	  (!(defined $Caseman::img2uni{$Args::args{'img'}})) || 
 	  (!(defined $Caseman::img2dls{$Args::args{'img'}})) || 
-	  ((defined $Caseman::img2dls{$Args::args{'img'}}) && (!(defined $Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}})))) { 
+	  ( (defined $Caseman::img2dls{$Args::args{'img'}}) && 
+	   ((!(defined $Caseman::img2str{$Caseman::img2dls{$Args::args{'img'}}})) || 
+	   (!(defined $Caseman::img2uni{$Caseman::img2dls{$Args::args{'img'}}}))))) { 
 		print "</tr></table><hr>\n";
 	}
 
@@ -2490,194 +2551,222 @@ sub img_del {
 
 
 # Make a strings -t d file for the image to decrease the search time
+# Can make both ASCII and Unicode strings files
 sub img_makestr {
-	Args::check_fname(); Args::check_fname_mode(); 
+	Print::print_html_header("Extracting Strings");
 
-	Print::print_html_header("Extracting ASCII Strings");
-
-	my $fname = Args::get_fname();
-	my $fname_rel = Args::get_fname_rel();
-	my $fname_mode = $Args::args{'fname_mode'};
 	my $ftype = Args::get_ftype();
-
-	if ((-e "$fname") && ($FNAME_MODE_INIT == $fname_mode)) {
-		print "File Already Exists: $fname_rel\n";
-
-		my $hidden = 
-		  "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_CASEMAN\">\n".
-		  "<input type=\"hidden\" name=\"view\" value=\"$Caseman::IMG_MAKESTR\">\n".
-		  "<input type=\"hidden\" name=\"img\" value=\"$Args::args{'img'}\">\n".
-		  Args::make_hidden();
-
-		$hidden .= "<input type=\"hidden\" name=\"md5\" value=\"$Args::args{'md5'}\">\n" 
-			if (exists $Args::args{'md5'});
-
-		print "<form action=\"$::PROGNAME\" method=\"get\">\n".
-		  "New Name: <input type=\"text\" name=\"fname\">\n".
-		  "<table cellspacing=\"30\" cellpadding=\"2\"><tr><td>".
-		  "$hidden".
-		  "<input type=\"hidden\" name=\"fname_mode\" value=\"$FNAME_MODE_INIT\">\n".
-		  "<input type=\"image\" src=\"pict/but_new_name.jpg\" ". 
-		  "width=79 height=20 alt=\"Use New Name\" border=\"0\">\n".
-		  "</form></td>\n";
-
-		print "<td><form action=\"$::PROGNAME\" method=\"get\">\n".
-		  "$hidden".
-		  "<input type=\"hidden\" name=\"fname\" value=\"$Args::args{'fname'}\">\n".
-		  "<input type=\"hidden\" name=\"fname_mode\" value=\"$FNAME_MODE_OVER\">\n".
-		  "<input type=\"image\" src=\"pict/but_replace.jpg\" ". 
-		  "width=66 height=20 alt=\"Replace\" border=\"0\">\n".
-		  "</form></td></tr></table>";
-
-		  return 0;
-	}
+	my $ascii = 0;
+	my $uni = 0;
 
 	my $img = Args::get_img('img');
+	my $img_rel = $Args::args{'img'};
+	(my $img_dir, my $img_sh) = split (/\//,$img_rel);
 
-	print "Extracting strings from <tt>$Args::args{'img'}</tt> and saving to ".
-	  "<tt>$Args::args{'fname'}</tt><br><br>\n";
-
-	Print::log_host_inv ("$Args::args{'img'}: Saving ASCII strings to $fname_rel");
-
-	local *OUT;
-
-    my $hit_cnt = 0;
-    $SIG{ALRM} = sub {
-        if (($hit_cnt++ % 5) == 0) {
-            print "+";
-        } else {
-            print "-";
-        }
-        alarm(5);
-    };
-
-    alarm(5);
-
-	Exec::exec_pipe (*OUT,
-	  "'$::STRINGS_EXE' -a $::STR_DEC '$img' > '$fname'");
-	print $_ while ($_ = Exec::read_pipe_line(*OUT));
-	close (OUT);
-
-	$SIG{ALRM} = 'DEFAULT';
-
-	print "<br>\n" 
-      if ($hit_cnt != 0);
-
-	# Verify that it worked
-	unless (open (STR, "$fname")) { 
-		print "Error opening $fname<br>\n".
-		  "Either an error occurred while generating the file or ".
-		  "no ASCII strings exist";
-		return (1);
-	}
-
-	my $sz = 0;
-	while (<STR>) {
-		unless (/^\s*\d+\s+\S.*$/) {
-			print ("Error making strings file: $_");
-			return (1);
+	if ((exists $Args::args{'str'}) && ($Args::args{'str'} == 1)) {
+		if (exists $Caseman::img2str{$img_rel}) {
+			Print::print_err ("Image already has an ASCII strings file: $img_rel");
 		}
-		$sz = 1;
-		last;
+		$ascii = 1;
 	}
 
-	if ($sz == 0) {
-		print "Strings file has no valid entries, there could be no ASCII".
-		  " strings in the original image";
+	if ((exists $Args::args{'uni'}) && ($Args::args{'uni'} == 1)) {
+		if (exists $Caseman::img2uni{$img_rel}) {
+			Print::print_err ("Image already has a Unicode strings file: $img_rel");
+		}
 
-		print "<form action=\"$::PROGNAME\" method=\"get\">\n".
-		  "<input type=\"hidden\" name=\"img\" value=\"$Args::args{'img'}\">\n".
-		  "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_CASEMAN\">\n".
-		  "<input type=\"hidden\" name=\"view\" value=\"$Caseman::IMG_DETAILS\">\n".
-		  Args::make_hidden().
-		  "<input type=\"image\" src=\"pict/but_ok.jpg\" ".        
-		  "width=43 height=20 alt=\"Ok\" border=\"0\">\n</form>";
-		return (1);
+		$uni = 1;
+	}
+	if (($uni == 0) && ($ascii == 0)) {
+		goto str_egress;
 	}
 
-	close (STR);
 
-	# append to config
-	Caseman::update_host_config("strings", $fname_rel, 
-	  "$Args::args{'img'}");
-	print "<tt>$fname_rel</tt> added to host config file<br><br>";
+	if ($ascii == 1) {
+		my $fname_rel = "$::DATADIR/${img_sh}.asc";
+		my $fname = "$::host_dir"."$fname_rel";	
+
+		if (-e "$::host_dir"."$fname_rel") {
+			my $i = 1;
+			$i++
+			  while (-e "$::host_dir"."$::DATA_DIR/"."$img-$i.asc"); 
+	
+			$fname_rel = "$::DATADIR/${img_sh}-$i.asc";
+			$fname = "$::host_dir"."$fname_rel";	
+		}
+
+		print "Extracting ASCII strings from <tt>$img_rel</tt><br>\n";
+
+		Print::log_host_inv ("$img_rel: Saving ASCII strings to $fname_rel");
+
+		local *OUT;
+
+		my $hit_cnt = 0;
+		$SIG{ALRM} = sub {
+			if (($hit_cnt++ % 5) == 0) {
+				print "+";
+			} else {
+				print "-";
+			}
+			alarm(5);
+		};
+
+		alarm(5);
+
+		Exec::exec_pipe (*OUT,
+		  "'$::TSKDIR/sstrings' -a -t d '$img' > '$fname'");
+		print $_ while ($_ = Exec::read_pipe_line(*OUT));
+		close (OUT);
+
+		$SIG{ALRM} = 'DEFAULT';
+
+		print "<br>\n" if ($hit_cnt != 0);
+
+		# Verify that it worked
+		unless (open (STR, "$fname")) { 
+			print("Error opening $fname<br>\n".
+			  "Either an error occurred while generating the file or ".
+			  "no ASCII strings exist<br>");
+			goto str_uni;
+		}
+
+		# append to config
+		Caseman::update_host_config("strings", $fname_rel, 
+		  "$img_rel");
+		print "Host configuration file updated<br>";
 
 
-	$Caseman::img2ftype{$fname_rel} = "strings";
-	$Caseman::mod2img{$fname_rel} = $Args::args{'img'};
-	$Caseman::img2str{$Args::args{'img'}} = $fname_rel;
+		$Caseman::img2ftype{$fname_rel} = "strings";
+		$Caseman::mod2img{$fname_rel} = $img_rel;
+		$Caseman::img2str{$img_rel} = $fname_rel;
 
-    # Calculate MD5
-    if ((exists $Args::args{'md5'}) && ($Args::args{'md5'} == 1)) {
-        print "Calculating MD5 Value<br><br>\n";
-        my $m = Hash::int_create_wrap ($fname, $fname_rel);
-        print "MD5 Value: <tt>$m</tt><br><br>\n";
-    }
+		# Calculate MD5
+		if ((exists $Args::args{'md5'}) && ($Args::args{'md5'} == 1)) {
+			print "Calculating MD5 Value<br><br>\n";
+			my $m = Hash::int_create_wrap ($fname, $fname_rel);
+			print "MD5 Value: <tt>$m</tt><br><br>\n";
+		}
+	}
 
-	my $dest_img = $Args::args{'img'};
+str_uni:
+
+	if ($uni == 1) {
+
+		my $fname_rel = "$::DATADIR/${img_sh}.uni";
+		my $fname = "$::host_dir"."$fname_rel";	
+
+		if (-e "$::host_dir"."$fname_rel") {
+			my $i = 1;
+			$i++
+			  while (-e "$::host_dir"."$::DATADIR/"."$img-$i.uni"); 
+	
+			$fname_rel = "$::DATADIR/${img_sh}-$i.uni";
+			$fname = "$::host_dir"."$fname_rel";	
+		}
+
+		print "<hr>\n" if ($ascii == 1);
+
+		print "Extracting Unicode strings from <tt>$img_rel</tt><br>\n";
+
+		Print::log_host_inv ("$img_rel: Saving Unicode strings to $fname_rel");
+
+		local *OUT;
+
+		my $hit_cnt = 0;
+		$SIG{ALRM} = sub {
+			if (($hit_cnt++ % 5) == 0) {
+				print "+";
+			} else {
+				print "-";
+			}
+			alarm(5);
+		};
+
+		alarm(5);
+
+		Exec::exec_pipe (*OUT,
+		  "'$::TSKDIR/sstrings' -a -t d -e l '$img' > '$fname'");
+		print $_ while ($_ = Exec::read_pipe_line(*OUT));
+		close (OUT);
+
+		$SIG{ALRM} = 'DEFAULT';
+
+		print "<br>\n" if ($hit_cnt != 0);
+
+		# Verify that it worked
+		unless (open (STR, "$fname")) { 
+			print "Error opening $fname<br>\n".
+			  "Either an error occurred while generating the file or ".
+			  "no Unicode strings exist";
+			goto str_egress;
+		}
+
+
+		# append to config
+		Caseman::update_host_config("unistrings", $fname_rel, 
+		  "$img_rel");
+		print "Host configuration file updated<br>";
+
+
+		$Caseman::img2ftype{$fname_rel} = "strings";
+		$Caseman::mod2img{$fname_rel} = $img_rel;
+		$Caseman::img2uni{$img_rel} = $fname_rel;
+
+		# Calculate MD5
+		if ((exists $Args::args{'md5'}) && ($Args::args{'md5'} == 1)) {
+			print "Calculating MD5 Value<br><br>\n";
+			$m = Hash::int_create_wrap ($fname, $fname_rel);
+			print "MD5 Value: <tt>$m</tt><br><br>\n";
+		}
+	}
+
+
+str_egress:
+
+	my $dest_img = $img_rel;
 	# We need to return with a real image to IMG_DETAILS so check the mod
-	$dest_img = $Caseman::mod2img{$Args::args{'img'}}
-	  if (defined $Caseman::mod2img{$Args::args{'img'}});
+	$dest_img = $Caseman::mod2img{$img_rel}
+	  if (defined $Caseman::mod2img{$img_rel});
 
-
-    print "<a href=\"$::PROGNAME?$Args::baseargs_noimg&mod=$::MOD_CASEMAN&".
-      "view=$Caseman::IMG_DETAILS&img=$dest_img\" target=_top>Image Details</a><p>\n";
+	print "<hr><a href=\"$::PROGNAME?$Args::baseargs_noimg&mod=$::MOD_CASEMAN&".
+	  "view=$Caseman::IMG_DETAILS&img=$dest_img\" target=_top>Image Details</a><p>\n";
     
-    print "<a href=\"$::PROGNAME?mod=$::MOD_FRAME&submod=$::MOD_KWSRCH&$Args::baseargs\"".
-      " target=\"_top\">Keyword Search</a>\n";
+	print "<a href=\"$::PROGNAME?mod=$::MOD_FRAME&submod=$::MOD_KWSRCH&$Args::baseargs\"".
+	  " target=\"_top\">Keyword Search</a>\n";
 
 	Print::print_html_footer();
-    return 0;
+
+	return 0;
 };
 
 sub img_makedls {
-	Args::check_fname(); 
-	Args::check_fname_mode(); 
-
 	Print::print_html_header("Extracting Unallocated Space");
 
-	my $fname = Args::get_fname();
-	my $fname_rel = Args::get_fname_rel();
-	my $fname_mode = $Args::args{'fname_mode'};
-
-	if ((-e "$fname") && ($FNAME_MODE_INIT == $fname_mode)) {
-		print "File Already Exists: $fname_rel\n";
-		my $hidden = 
-		  "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_CASEMAN\">\n".
-		  "<input type=\"hidden\" name=\"view\" value=\"$Caseman::IMG_MAKEDLS\">\n".
-		  "<input type=\"hidden\" name=\"img\" value=\"$Args::args{'img'}\">\n".
-		  Args::make_hidden();
-
-		$hidden .= "<input type=\"hidden\" name=\"md5\" value=\"$Args::args{'md5'}\">\n" 
-			if (exists $Args::args{'md5'});
-
-		print "<form action=\"$::PROGNAME\" method=\"get\">\n".
-		  "New Name: <input type=\"text\" name=\"fname\"> ".
-		  "<table cellspacing=\"30\" cellpadding=\"2\"><tr><td>".
-		  "$hidden".
-		  "<input type=\"hidden\" name=\"fname_mode\" value=\"$FNAME_MODE_INIT\">\n".
-		  "<input type=\"image\" src=\"pict/but_new_name.jpg\" ".               
-		  "width=79 height=20 alt=\"Use New Name\" border=\"0\">\n".
-		  "</form></td>\n";
-
-		print "<td><form action=\"$::PROGNAME\" method=\"get\">\n".
-		  "<input type=\"image\" src=\"pict/but_replace.jpg\" ".               
-		  "width=66 height=20 alt=\"Replace\" border=\"0\"><br>\n".
-		  "$hidden".
-		  "<input type=\"hidden\" name=\"fname\" value=\"$Args::args{'fname'}\">\n".
-		  "<input type=\"hidden\" name=\"fname_mode\" value=\"$FNAME_MODE_OVER\">\n".
-		  "</form></td></tr></form>";
-
-		  return 0;
-	}
-
 	my $img = Args::get_img('img');
 	my $ftype = Args::get_ftype();
 
+	my $img_rel = $Args::args{'img'};
+	(my $img_dir, my $img_sh) = split (/\//,$img_rel);
+	$img_sh = $1 
+	  if ($img_sh =~ /^(.*?)\.dd$/);
+
+	my $fname_rel = "$::DATADIR/${img_sh}.unalloc";
+	my $fname = "$::host_dir"."$fname_rel";	
+
+	if (-e "$::host_dir"."$fname_rel") {
+		my $i = 1;
+		$i++
+		  while (-e "$::host_dir"."$::DATA_DIR/"."$img-$i.unalloc"); 
+
+		$fname_rel = "$::DATADIR/${img_sh}-$i.unalloc";
+		$fname = "$::host_dir"."$fname_rel";	
+	}
+
+
 	Print::log_host_inv ("$Args::args{'img'}: Saving unallocated data to $fname_rel");
 
 	print "Extracting unallocated data from <tt>$Args::args{'img'}</tt> and ".
-	  "saving to <tt>$fname_rel</tt><br><br>\n";
+	  "saving to <tt>$fname_rel</tt><br>\n";
 
 	local *OUT;
 
@@ -2705,7 +2794,7 @@ sub img_makedls {
 	# append to fsmorgue 
 	Caseman::update_host_config("dls", $fname_rel, $Args::args{'img'}); 
 
-	print "<tt>$fname_rel</tt> added to host config file<br><br>";
+	print "Host configuration file updated<br>\n";
 
 	$Caseman::img2ftype{$fname_rel} = "dls";
 	$Caseman::mod2img{$fname_rel} = $Args::args{'img'};
@@ -2713,7 +2802,7 @@ sub img_makedls {
 
     # Calculate MD5
     if ((exists $Args::args{'md5'}) && ($Args::args{'md5'} == 1)) {
-        print "Calculating MD5 Value<br><br>\n";
+        print "Calculating MD5 Value<br>\n";
         my $m = Hash::int_create_wrap ($fname, $fname_rel);
         print "MD5 Value: <tt>$m</tt><br><br>\n";
     }
@@ -2725,7 +2814,7 @@ sub img_makedls {
       "img=$fname_rel\" target=\"_top\">Keyword Search</a>\n";
 
 	Print::print_html_footer();
-    return 0;
+	return 0;
 };
 
 1;
