@@ -64,11 +64,6 @@ sub main {
     Args::check_view();    
     my $view = Args::get_view();
 
-    if ($view == $Data::BLANK) {
-        blank();	
-        return 0;
-    }
-
 
     # Check Basic Args
     Args::check_img('img');
@@ -86,6 +81,9 @@ sub main {
     elsif ($view == $Data::LIST) {
         return list();	
     }
+    elsif ($view == $Data::BLANK) {
+        return blank();
+    }
 
     # These windows do need the data unit address
     Args::check_block(); 
@@ -430,7 +428,7 @@ sub content_menu {
 	  "&block=$block&len=$len\" target=\"_blank\">report</a>)</td>\n".
 	  "<td>*</td>\n";
 
-	print "<td>Strings (";
+	print "<td>ASCII Strings (";
 	if ($sort == $Data::SORT_STR) {
 		print "display - ";
 	} else {
@@ -448,9 +446,9 @@ sub content_menu {
 	# Special case for 'dls' b.c. we need to specify original data unit size
 	local *OUT;
 	if ($ftype eq 'dls') {
-		  Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype -u $bs '$img' $block | '$::TSKDIR/file' -z -b -");
+		  Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype -u $bs '$img' $block | '$::FILE_EXE' -z -b -");
 	} else {
-		Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype '$img' $block | '$::TSKDIR/file' -z -b -");
+		Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype '$img' $block | '$::FILE_EXE' -z -b -");
 	}
 	my $file_type = Exec::read_pipe_line(*OUT);
 	close (OUT);
@@ -559,9 +557,9 @@ sub content {
 		Exec::exec_pipe(*OUT,"'$::TSKDIR/dcat' -f $ftype $usize_str -a '$img' $block $len");
 	}
 	elsif ($sort == $Data::SORT_STR) {
-		print "String ".$str;
+		print "ASCII String ".$str;
 		Print::log_host_inv ("$Args::args{'img'}: Displaying string $log_str");
-		Exec::exec_pipe(*OUT,"'$::TSKDIR/dcat' -f $ftype $usize_str '$img' $block $len | '$::STRINGS_EXE' -a");
+		Exec::exec_pipe(*OUT,"'$::TSKDIR/dcat' -f $ftype $usize_str '$img' $block $len | '$::TSKDIR/sstrings' -a");
 	}
 	print $_ while ( $_ = Exec::read_pipe_data(*OUT, 512) );
 	close (OUT);
@@ -597,7 +595,7 @@ sub report {
 		Print::log_host_inv ("$Args::args{'img'}: Generating ASCII report on data unit $block");
 		$type = "ascii";
 	} elsif ($sort == $Data::SORT_STR) {
-		Print::log_host_inv ("$Args::args{'img'}: Generating strings report on data unit $block");
+		Print::log_host_inv ("$Args::args{'img'}: Generating ASCII strings report on data unit $block");
 		$type = "string";
 	} elsif ($sort == $Data::SORT_HEX) {
 		Print::log_host_inv ("$Args::args{'img'}: Generating hex report on data unit $block");
@@ -672,7 +670,7 @@ sub report {
 	} elsif ($sort == $Data::SORT_ASC) {
 		Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype $usize_str -a '$img' $block $len | '$::TSKDIR/md5'");
 	} elsif ($sort == $Data::SORT_STR) {
-		Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype $usize_str '$img' $block $len | '$::STRINGS_EXE' -a | '$::TSKDIR/md5'");
+		Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype $usize_str '$img' $block $len | '$::TSKDIR/sstrings' -a | '$::TSKDIR/md5'");
 	}
 
 	$md5 = Exec::read_pipe_line(*OUT);
@@ -702,7 +700,7 @@ sub report {
 		Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype $usize_str -a '$img' $block $len");
 	}
 	elsif ($sort == $Data::SORT_STR) {
-		Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype $usize_str '$img' $block $len | '$::STRINGS_EXE' -a");
+		Exec::exec_pipe(*OUT, "'$::TSKDIR/dcat' -f $ftype $usize_str '$img' $block $len | '$::TSKDIR/sstrings' -a");
 	}
 	Print::print_output($_) while ($_ = Exec::read_pipe_data(*OUT, 512));
 	close (OUT);
@@ -819,7 +817,11 @@ sub export {
 # Blank Page
 sub blank { 
     Print::print_html_header("Data Unit Blank Page");
-    print "<!-- This Page Intentionally Left Blank -->\n";
+    my $ftype = Args::get_ftype();
+
+    print "<center><h3>Data Unit Mode</h3><br>\n".
+	    "Here you can view the contents of any $Fs::addr_unit{$ftype} in the file system.<br>\n".
+	    "Enter the address in the field on the left.\n";
     Print::print_html_footer();
     return 0;
 };
