@@ -233,7 +233,9 @@ sub dir_list {
 
 	# Field to enter a directory into:
     print "<p><form action=\"$::PROGNAME\" method=\"get\" target=\"list\">\n".
-      "<b>View Directory:</b><br><tt>$Args::args{'mnt'}</tt>".
+      "<center><b>Directory Seek</b></center><br>".
+      "<font size=2>Enter the name of a directory that you want to view<br></font>".
+      "<tt>$Args::args{'mnt'}</tt>".
       "<input type=\"text\" name=\"dir\" size=24 maxlength=100>\n".
       "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_FILE\">\n".
       "<input type=\"hidden\" name=\"view\" value=\"$File::FILE_LIST_DIR\">\n".
@@ -249,7 +251,8 @@ sub dir_list {
 
 	# Field to enter a name into:
     print "<hr><p><form action=\"$::PROGNAME\" method=\"get\" target=\"list\">\n".
-      "<b>Search For File Name:</b><br>".
+      "<center><b>File Name Search</b></center><br>".
+      "<font size=2>Enter a Perl regular expression for the file names you want to find<br></font>\n".
       "<input type=\"text\" name=\"dir\" size=24 maxlength=100>\n".
       "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_FILE\">\n".
       "<input type=\"hidden\" name=\"view\" value=\"$File::FILE_LIST_FILE\">\n".
@@ -258,7 +261,7 @@ sub dir_list {
       "<input type=\"hidden\" name=\"sort\" value=\"$Args::args{'sort'}\">\n".
       "<input type=\"hidden\" name=\"dirmode\" value=\"$Args::args{'dirmode'}\">\n".
       Args::make_hidden().
-	  "(Perl regular expression)<br>\n".
+	  "<br>\n".
 
     # Search Button
       "<input type=\"image\" src=\"pict/but_search.jpg\" ".
@@ -1728,10 +1731,10 @@ sub content_menu {
 
 	if ($recmode == $File::REC_YES) {
 		Exec::exec_pipe(*OUT, 
-		  "'$::TSKDIR/icat' -f $ftype -r '$img' $meta | '$::TSKDIR/file' -z -b -");
+		  "'$::TSKDIR/icat' -f $ftype -r '$img' $meta | '$::FILE_EXE' -z -b -");
 	} else {
 		Exec::exec_pipe(*OUT, 
-		  "'$::TSKDIR/icat' -f $ftype '$img' $meta | '$::TSKDIR/file' -z -b -");
+		  "'$::TSKDIR/icat' -f $ftype '$img' $meta | '$::FILE_EXE' -z -b -");
 	}
 
 
@@ -1755,7 +1758,7 @@ sub content_menu {
 	  "<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::REPORT&".
           "sort=$FIL_SORT_ASC$url\" target=\"_blank\">report</a>)</td>\n".
 	  "<td>*</td>\n".
-	  "<td>Strings (".
+	  "<td>ASCII Strings (".
 	  "<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::CONT&".
           "sort=$FIL_SORT_STR$url\" target=\"cont2\">display</a> - ".
 	  "<a href=\"$::PROGNAME?mod=$::MOD_FILE&view=$File::REPORT&".
@@ -1824,9 +1827,9 @@ sub content {
 	} elsif ($sort == $FIL_SORT_STR) {
 		Print::log_host_inv ("$Args::args{'img'}: Viewing $fname ($meta) as strings");
 
-		Exec::exec_pipe(*OUT, "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::STRINGS_EXE' -a");
+		Exec::exec_pipe(*OUT, "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::TSKDIR/sstrings' -a");
 
-		print "String Contents Of File: $fname\n\n\n\n";
+		print "ASCII String Contents Of File: $fname\n\n\n\n";
 		Print::print_output ($_) while ($_ = Exec::read_pipe_line(*OUT));
 		close (OUT);
 	}
@@ -1912,7 +1915,7 @@ sub report {
 		Print::log_host_inv ("$Args::args{'img'}: Generating ASCII report for $fname ($meta)");
 		$type = "ASCII";
 	}elsif ($sort == $FIL_SORT_STR) {
-		Print::log_host_inv ("$Args::args{'img'}: Generating strings report for $fname ($meta)");
+		Print::log_host_inv ("$Args::args{'img'}: Generating ASCII strings report for $fname ($meta)");
 		$type = "string";
 	} else {
 		print "\n\ninvalid sort value";
@@ -1948,9 +1951,24 @@ sub report {
 		print "MD5 of recovered file: $md5\n";
 	}
 
+	Exec::exec_pipe(*OUT, 
+	  "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::TSKDIR/sha1'");
+	my $sha1 = Exec::read_pipe_line(*OUT);
+	close (OUT);
+
+	$sha1 = "Error getting SHA-1 Value"
+	  if ((!defined $sha1) || ($sha1 eq ""));
+
+	chomp $sha1;
+	if ($recflag eq "") {
+		print "SHA-1 of file: $sha1\n";
+	} else {
+		print "SHA-1 of recovered file: $sha1\n";
+	}
+
 	if ($sort == $FIL_SORT_STR) {
 		Exec::exec_pipe(*OUT, 
-		  "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::STRINGS_EXE' -a | '$::TSKDIR/md5'");
+		  "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::TSKDIR/sstrings' -a | '$::TSKDIR/md5'");
 		$md5 = Exec::read_pipe_line(*OUT);
 		close (OUT);
 
@@ -1958,7 +1976,19 @@ sub report {
 		  if ((!defined $md5) || ($md5 eq ""));
 
 		chomp $md5;
-		print "MD5 of strings: $md5\n";
+		print "MD5 of ASCII strings: $md5\n";
+
+
+		Exec::exec_pipe(*OUT, 
+		  "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::TSKDIR/sstrings' -a | '$::TSKDIR/sha1'");
+		$sha1 = Exec::read_pipe_line(*OUT);
+		close (OUT);
+
+		$sha1 = "Error getting SHA-1 Value"
+		  if ((!defined $sha1) || ($sha1 eq ""));
+
+		chomp $sha1;
+		print "SHA-1 of ASCII strings: $sha1\n";
 	}
 
 	print "\nImage: $img\n";
@@ -1979,7 +2009,7 @@ sub report {
 
 	# File Type
 	Exec::exec_pipe(*OUT, 
-	  "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::TSKDIR/file' -z -b -");
+	  "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::FILE_EXE' -z -b -");
 	my $file_type = Exec::read_pipe_line(*OUT);
 	close (OUT);
 
@@ -2002,7 +2032,7 @@ sub report {
 		close (OUT);
 	} elsif ($sort == $FIL_SORT_STR) {
 		Exec::exec_pipe (*OUT,
-		  "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::STRINGS_EXE' -a");
+		  "'$::TSKDIR/icat' -f $ftype $recflag '$img' $meta | '$::TSKDIR/sstrings' -a");
 		Print::print_output($_) while ($_ = Exec::read_pipe_line(*OUT));
 		close (OUT);
 	}
@@ -2082,10 +2112,14 @@ sub md5list {
 
 # Blank Page
 sub blank {
-    Print::print_html_header("");
-    print "<!-- This Page Intentionally Left Blank -->\n";
+	Print::print_html_header("");
+	print "<p><center><h3>File Browsing Mode</h3><br>\n".
+		"In this mode, you can select a file or directory.<br>\n".
+	        "File contents will be shown in this window.<br>\n".
+		"More file details can be found using the Metadata link at the end of the list (on the right).<br>\n".
+		"You can also sort the files using the column headers<br>\n";
 	Print::print_html_footer();
-    return 0;
+	return 0;
 };
 
 
