@@ -94,23 +94,46 @@ my $STRING = 0;
 # Form to enter search data
 sub enter {
 	Print::print_html_header("Search on $Args::args{'img'}");
+	my $ftype = Args::get_ftype();
+
+	if ($ftype eq 'dls') {
+		print "<center><h3>Keyword Search of Unallocated Space</h3>\n";
+	} 
+	elsif ($ftype eq 'swap') {
+		print "<center><h3>Keyword Search of swap partition</h3>\n";
+	}
+	elsif ($ftype eq 'raw') {
+		print "<center><h3>Keyword Search of raw data</h3>\n";
+	} 
+	else {
+		print "<center><h3>Keyword Search of Allocated and Unallocated Space</h3>\n";
+	}
+
+# @@@ Fix this - caused by writing all results to a file
+	if ($::LIVE == 1) {
+		Print::print_err("<center>Keyword searching is temporarily not available during live analysis mode</center>");
+	}
 
-	print "<center><h3>Keyword Search on <tt>$Args::args{'img'}</tt></h3>\n";
 
 	print "<form action=\"$::PROGNAME\" method=\"get\">\n".
-	  "Enter String: <input type=\"text\" name=\"str\"><br><br>\n".
+	  "Enter the keyword string or expression to search for:<br> <input type=\"text\" name=\"str\"><br><br>\n".
 	  Args::make_hidden().
 	  "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_KWSRCH\">\n".
 	  "<input type=\"hidden\" name=\"view\" value=\"$Kwsrch::RESULTS_FR\">\n".
-	  "<input type=\"hidden\" name=\"img\" value=\"$Args::args{'img'}\">\n".
-	  "<input type=\"checkbox\" name=\"srch_case\" value=\"$CASE_INSENS\">".
-	  "Case Insensitive\n".
-	  "<input type=\"checkbox\" name=\"regexp\" value=\"$REG_EXP\">".
-	  "Regular Expression<br><br>\n".
+	  "<input type=\"hidden\" name=\"img\" value=\"$Args::args{'img'}\">\n";
+
+	print "<table width=400><tr>\n".
+	  "<td width=200 align=center><input type=\"checkbox\" name=\"ascii\" value=\"1\" CHECKED>".
+	  "ASCII \n</td>".
+	  "<td width=200 align=center><input type=\"checkbox\" name=\"unicode\" value=\"1\" CHECKED>".
+	  "Unicode</td></tr>\n".
+	  "<tr><td align=center><input type=\"checkbox\" name=\"srch_case\" value=\"$CASE_INSENS\">".
+	  "Case Insensitive</td>\n".
+	  "<td align=center><input type=\"checkbox\" name=\"regexp\" value=\"$REG_EXP\">\n".
+	  "<tt>grep</tt> Regular Expression</td></tr></table>\n".
 	  "<input type=\"image\" src=\"pict/but_search.jpg\" ".
 	  "alt=\"Search\" border=\"0\">\n</form>\n";
 
-	my $ftype = Args::get_ftype();
 
 	if ($::LIVE == 0) {
 		print "<table width=600><tr>\n";
@@ -142,7 +165,8 @@ sub enter {
 		}
 
 		# Strings Button
-		if (!(exists $Caseman::img2str{$Args::args{'img'}})) {
+		if ((!(exists $Caseman::img2str{$Args::args{'img'}})) || 
+		  (!(exists $Caseman::img2uni{$Args::args{'img'}}))) {
 
 			my $dest_img = $Args::args{'img'};
 			$dest_img = $Caseman::mod2img{$Args::args{'img'}} 
@@ -177,7 +201,7 @@ sub enter {
 	}
 
 	print "<a href=\"help/grep.html\" target=\"_blank\">".
-	  "grep cheat sheet</a>\n<br><br>\n";
+	  "Regular Expression Cheat Sheet</a>\n<br><br>\n";
 
 	print "<p><font color=\"red\">NOTE:</font> The keyword search runs ".
 	  "<tt>grep</tt> on the image.<br>\n".
@@ -188,7 +212,7 @@ sub enter {
 
 	# Section for previous searches
 	if ($::LIVE == 0) {
-		my $srch_name = srch_fname(0);
+		my $srch_name = get_srch_fname(0);
 		if (-e $srch_name) {
 			print "<hr><h3>Previous Searches</h3>\n".
 			  "<table width=600>\n";
@@ -197,7 +221,7 @@ sub enter {
 			# Cycle through the files
 			for (my $srch_idx = 0; ;$srch_idx++) {
 
-				$srch_name = srch_fname($srch_idx);
+				$srch_name = get_srch_fname($srch_idx);
 			
 				last unless (-e $srch_name);
 
@@ -208,6 +232,7 @@ sub enter {
 				}
 				my $prev_str = "";
 				my $prev_cnt = 0;
+
 				while (<SRCH>) {
 					unless (/^(\d+)\|(.*?)?\|(.*)$/) {
 						print "Error pasing header of search file: $srch_name\n";
@@ -260,12 +285,15 @@ sub enter {
 
 		print "<tr>\n" if ($row_idx == 0); 
 
+# @@@ Make a unicode option in predefined
+
 		print "  <td align=center width=150>\n".
 	  	  "<form action=\"$::PROGNAME\" method=\"get\">\n".
 	  	  "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_KWSRCH\">\n".
 	  	  "<input type=\"hidden\" name=\"view\" value=\"$Kwsrch::RESULTS_FR\">\n".
 	  	  "<input type=\"hidden\" name=\"img\" value=\"$Args::args{'img'}\">\n".
 	  	  "<input type=\"hidden\" name=\"str\" value=\"$Kwsrch::auto_srch{$r}\">\n".
+	  	  "<input type=\"hidden\" name=\"ascii\" value=\"1\">\n".
 		  Args::make_hidden();
 
 		if ($Kwsrch::auto_srch_reg{$r} == 1) {
@@ -311,10 +339,18 @@ sub results_fr {
 		$regexp = "&regexp=$Args::args{'regexp'}" 
 		  if (exists $Args::args{'regexp'});
 
+		my $ascii = "";
+		$ascii = "&ascii=$Args::args{'ascii'}" 
+		  if (exists $Args::args{'ascii'});
+
+		my $unicode = "";
+		$unicode = "&unicode=$Args::args{'unicode'}" 
+		  if (exists $Args::args{'unicode'});
+
 		# Block List
 		print "<frame src=\"$::PROGNAME?".
                   "mod=$::MOD_KWSRCH&view=$Kwsrch::RUN&".
-		  "$Args::baseargs$srch_case$regexp&str=$Args::enc_args{'str'}\">\n";
+		  "$Args::baseargs$srch_case$regexp&str=$Args::enc_args{'str'}$ascii$unicode\">\n";
 	}
 	elsif (exists $Args::args{'srchidx'}) {
 		Args::check_srchidx();
@@ -354,8 +390,9 @@ sub find_srch_file {
 
 
 
-# Pass the index and get the full path of the file returned
-sub srch_fname {
+# Pass the index 
+# return the full path of the file returned
+sub get_srch_fname {
     my $idx = shift;
     my $tmp_img = $Args::args{'img'};
     $tmp_img =~ tr/\//\-/;
@@ -374,30 +411,13 @@ sub load {
 		return 1;
 	}
 
-	my $srch_name = srch_fname($Args::args{'srchidx'});
-	unless (open (SRCH, "$srch_name")) {
-		print "Error opening search file: $srch_name\n";
-		return 1;
-	}
+	my $srch_name = get_srch_fname($Args::args{'srchidx'});
 
-	my @results;
-	my $prev_str = "";
-	my $grep_flag = "";
+	print "<b><a href=\"$::PROGNAME?mod=$::MOD_KWSRCH&view=$Kwsrch::ENTER&".
+          "$Args::baseargs\" ".
+	  "target=\"_parent\">New Search</a></b>\n<p>";
 
-	while (<SRCH>) {
-		if ($. == 1) {
-			unless (/^(\d+)\|(.*?)?\|(.*)$/) {
-				print "Error pasing header of search file: $srch_name\n";
-				return 1;
-			}
-			$grep_flag = $2;
-			$prev_str = $3;
-		} else {
-			push @results, "$_";
-		}
-	}
-	close (SRCH);
-	print_srch_results($prev_str, $grep_flag, \@results, $srch_name);
+	print_srch_results($srch_name);
 
 	Print::print_html_footer();
 	return 0;
@@ -420,13 +440,32 @@ sub run {
 	# Check for a search string 
 	if ($orig_str eq "") {
 		print "You must enter a string value to search<br>\n";
-		print "<b><a href=\"$::PROGNAME?mod=$::KWSRCH&view=$Kwsrch::ENTER&".
+		print "<b><a href=\"$::PROGNAME?mod=$::MOD_KWSRCH&view=$Kwsrch::ENTER&".
 		  "$Args::baseargs\" target=\"_parent\">New Search</a></b>\n<p>";
 		return 1;
 	}
 
-
 	my $log = "";			# Log entry string
+
+	my $ascii = 0;
+	my $unicode = 0;
+
+	if ((exists $Args::args{'ascii'}) && ($Args::args{'ascii'} == 1)) {
+		$ascii = 1;
+		$log .= "ASCII, ";
+	}
+	if ((exists $Args::args{'unicode'}) && ($Args::args{'unicode'} == 1)) {
+		$unicode = 1;
+		$log .= "Unicode, ";
+	}
+
+	if (($ascii == 0) && ($unicode == 0)) {
+		print "You must choose either ASCII or Unicode to search<br>\n";
+		print "<b><a href=\"$::PROGNAME?mod=$::MOD_KWSRCH&view=$Kwsrch::ENTER&".
+		  "$Args::baseargs\" target=\"_parent\">New Search</a></b>\n<p>";
+		return 1;
+	}
+
 	my $grep_flag = "";		# Flags to pass to grep
 
 	# Check if search is case insensitive
@@ -468,41 +507,6 @@ sub run {
 	# Get the addressable unit of image
 	my $bs = Args::get_unitsize();
 
-	local *OUT;
-
-	my $hit_cnt = 0;
-	$SIG{ALRM} = sub {
-		if (($hit_cnt++ % 5) == 0) {
-			print "+";
-		} else {
-			print "-";
-		}
-		alarm(5);
-	};
-
-	alarm(5);
-	print "<b>Searching</b>: ";
-
-	# if the string is less than 4 chars, then it will not be in the
-	# strings file so it will be searched for the slow way
-	if (length($orig_str) < 4) {
-		my $ltmp = length ($orig_str);
-		Exec::exec_pipe (*OUT, 
-		  "'$::STRINGS_EXE' -a $::STR_DEC -$ltmp '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
-	}
-	# Use the strings file if it exists
-	elsif (defined $Caseman::img2str{$Args::args{'img'}}) {
-		my $str_img = "$::host_dir"."$Caseman::img2str{$Args::args{'img'}}";
-		Exec::exec_pipe (*OUT, 
-		  "'$::GREP_EXE' $grep_flag '$grep_str' '$str_img'");
-	}
-	# Run strings on the image first and then grep that
-	else {
-		Exec::exec_pipe (*OUT, 
-		  "'$::STRINGS_EXE' -a $::STR_DEC '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
-	} 
-
-
 	# $norm_str is normalized to find the "hit" in the output
 	my $norm_str = $orig_str;
 
@@ -514,6 +518,73 @@ sub run {
 	# array to pass to printing method
 	my @results;
 
+	my $name_uni = "";
+	my $name_asc = "";
+
+	# round 0 is for ASCII and 1 is for Unicode 
+	for (my $i = 0; $i < 2; $i++) {
+
+		next if (($i == 0) && ($ascii == 0));
+		next if (($i == 1) && ($unicode == 0));
+
+		@results = ();
+
+		local *OUT;
+
+		my $hit_cnt = 0;
+		$SIG{ALRM} = sub {
+			if (($hit_cnt++ % 5) == 0) {
+				print "+";
+			} else {
+				print "-";
+			}
+			alarm(5);
+		};
+
+		alarm(5);
+		
+		if ($i == 0) {
+			print "<b>Searching for ASCII</b>: ";
+		} else {
+			print "<b>Searching for Unicode</b>: ";
+		}
+
+
+		# if the string is less than 4 chars, then it will not be in the
+		# strings file so it will be searched for the slow way
+		if (length($orig_str) < 4) {
+			my $ltmp = length ($orig_str);
+			if ($i == 0) {
+				Exec::exec_pipe (*OUT, 
+				  "'$::TSKDIR/sstrings' -a -t d -$ltmp '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
+			} else {
+				Exec::exec_pipe (*OUT, 
+				  "'$::TSKDIR/sstrings' -a -t d -e l -$ltmp '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
+			}
+		}
+		# Use the strings file if it exists
+		elsif (($i == 0) && (defined $Caseman::img2str{$Args::args{'img'}})) {
+		       	my $str_img = "$::host_dir"."$Caseman::img2str{$Args::args{'img'}}";
+			Exec::exec_pipe (*OUT, 
+			  "'$::GREP_EXE' $grep_flag '$grep_str' '$str_img'");
+		}
+		elsif (($i == 1) && (defined $Caseman::img2uni{$Args::args{'img'}})) {
+		       	my $str_img = "$::host_dir"."$Caseman::img2uni{$Args::args{'img'}}";
+			Exec::exec_pipe (*OUT, 
+			  "'$::GREP_EXE' $grep_flag '$grep_str' '$str_img'");
+		}
+		# Run strings on the image first and then grep that
+		else {
+			if ($i == 0) {
+				Exec::exec_pipe (*OUT, 
+				  "'$::TSKDIR/sstrings' -a -t d '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
+			} else {
+				Exec::exec_pipe (*OUT, 
+				  "'$::TSKDIR/sstrings' -a -t d -e l '$img' | '$::GREP_EXE' $grep_flag '$grep_str'");
+			}
+		} 
+
+
 	# Cycle through the results and put them in an array
 	while ( $_ = Exec::read_pipe_line(*OUT) ) {
 
@@ -543,12 +614,11 @@ sub run {
 
 
 			# There could be more than one keyword in the string
-			# so cylcle through all of them
+			# so cycle through all of them
 			my $psize = scalar (@results);
 			while (($idx = index ($hit_str, $norm_str, $idx)) > -1) {
 
-				my $b = int (($off + $idx) / $bs);
-				my $o = int (($off + $idx) % $bs);
+
 
 				# The summary of the hit starts 5 chars before it
 				my $sum_min = $idx - 5;
@@ -562,6 +632,14 @@ sub run {
 				# remove new lines
 				$sum_hit =~ s/\n/ /g;
 
+				# The actual offset for Unicode is 2 bytes per char
+				my $tmpidx = $idx;
+				$tmpidx *= 2
+				  if ($i == 1);
+
+				my $b = int (($off + $tmpidx) / $bs);
+				my $o = int (($off + $tmpidx) % $bs);
+
 				push @results, "${b}|${o}|$sum_hit";
 
 				# advance index to find next hit
@@ -593,6 +671,7 @@ sub run {
 	$SIG{ALRM} = 'DEFAULT';
 
 	print " <b>Done</b><br>";
+	my $cnt = scalar(@results);
 
 	my $srch_name = "";
 	if ($::LIVE == 0) {
@@ -605,17 +684,45 @@ sub run {
 		}
 
 		# Print the header 
-		my $cnt = scalar(@results);
-		print IDX "$cnt|${grep_flag}|${orig_str}\n";
+		if ($i == 0) {
+			print IDX "$cnt|${grep_flag}|${orig_str}|ascii\n";
+			$name_asc = $srch_name;
+		} else {
+			print IDX "$cnt|${grep_flag}|${orig_str}|unicode\n";
+			$name_uni = $srch_name;
+		}
 
-		for (my $i = 0; $i < $cnt; $i++) {
-			print IDX "$results[$i]\n";
+		for (my $a = 0; $a < $cnt; $a++) {
+			print IDX "$results[$a]\n";
 		}
 		close (IDX);
-		print " <b>Done</b><hr>\n";
+		print " <b>Done</b><br>\n";
+	}
+		if ($i == 0) {
+			print "$cnt hits";
+		       	print "- <a href=\"#ascii\">link to results</a>" if ($cnt > 0);
+			print "<br>\n";
+		} else {
+			print "$cnt hits";
+		       	print "- <a href=\"#unicode\">link to results</a>" if ($cnt > 0);
+			print "<br>\n";
+		}
+		print "<hr>\n";
 	}
 
-	print_srch_results($grep_str, $grep_flag, \@results, $srch_name);
+	print "<b><a href=\"$::PROGNAME?mod=$::MOD_KWSRCH&view=$Kwsrch::ENTER&".
+          "$Args::baseargs\" ".
+	  "target=\"_parent\">New Search</a></b>\n<p>";
+
+	if ($::LIVE == 0) {
+		if ($ascii == 1) {
+		 	print_srch_results($name_asc);
+		} 
+	
+		if ($unicode == 1) {
+		 	print_srch_results($name_uni);
+		} 
+	}
 
 	Print::print_html_footer();
 	return 0;
@@ -625,61 +732,101 @@ sub run {
 # Args are search string, grep flags, and array of hits
 sub print_srch_results {
 
-	if (scalar (@_) != 4) {
+	if (scalar (@_) != 1) {
 		print "Missing Args for print_srch_results()\n";
 		return 1;
 	}
 
-	my $grep_str = shift();
-	my $grep_flag = shift();
-	my @results = @{shift()};
-	my $srch_name = shift();
-	my $cnt = scalar(@results);
+	my $srch_name = shift;
 
 	my $ftype = Args::get_ftype();
 	my $addr_str = $Fs::addr_unit{$ftype};
 
-	print "<b><a href=\"$::PROGNAME?mod=$::MOD_KWSRCH&view=$Kwsrch::ENTER&".
-          "$Args::baseargs\" ".
-	  "target=\"_parent\">New Search</a></b>\n<p>";
-
-	my $grep_str_html = Print::html_encode($grep_str);
-	if ($cnt == 0) {    
-		print "<b><tt>$grep_str_html</tt> was not found</b><br>\n";
-	} elsif ($cnt == 1) {
-		print "<b>1 occurrence of <tt>$grep_str_html</tt> was found</b><br>\n";
-	} else {
-		print "<b>$cnt occurrences of <tt>$grep_str_html</tt> were found</b><br>\n";
+	unless (open (SRCH, "$srch_name")) {
+		print "Error opening search file: $srch_name\n";
+		return 1;
 	}
 
-	print "Search Options:<br>\n";
-	if ($grep_flag =~ /\-i/) {
-		print "&nbsp;&nbsp;Case Insensitive<br>\n";
-	} else {
-		print "&nbsp;&nbsp;Case Sensitive<br>\n";
-	}
-	if ($grep_flag =~ /\-E/) {
-		print "&nbsp;&nbsp;Regular Expression<br>\n";
-		
-	}
-
-	print "<hr>\n";
-
-	if ($cnt > 1000) {
-		print "There were more than <U>1000</U> hits.<br>\n";
-		print "Please revise the search to a managable amount.\n";
-		print "<p>The $cnt hits can be found in: <tt>$srch_name</tt><br>\n";
-		print "<p><b><a href=\"$::PROGNAME?mod=$::MOD_KWSRCH&".
-                  "view=$Kwsrch::ENTER&$Args::baseargs\" ".
-		  "target=\"_parent\">New Search</a></b>\n<p>";
-		return 0;
-	}
+	my @results;
+	my $grep_str = "";
+	my $grep_flag = "";
+	my $cnt = 0;
+	my $type = 0;  # ASCII iis 0 and Unicode is 1
 
 	my $prev = -1;
-	for (my $i = 0; $i < $cnt; $i++) {
 
-		unless ($results[$i] =~ /^(\d+)\|(\d+)\|(.*)?$/) {
-			print "Error parsing search array: $results[$i]\n";
+	while (<SRCH>) {
+
+		# The first line is a header
+		if ($. == 1) {
+			if (/^(\d+)\|(.*?)?\|(.*)$/)  {
+				$cnt = $1;
+				$grep_flag = $2;
+				$grep_str = $3;
+				$type = 0;
+			} else {
+				print "Error pasing header of search file: $srch_name\n";
+				close (SRCH);
+				return 1;
+			}
+
+			if ($grep_str =~ /^(.*?)\|unicode$/) {
+				$grep_str = $1;
+				$type = 1;
+			}
+			elsif ($grep_str =~ /^(.*?)\|ascii$/) {
+				$grep_str = $1;
+			}
+
+			my $grep_str_html = Print::html_encode($grep_str);
+			print "<hr>\n";
+			if ($type == 0) {
+				print "<a name=\"ascii\">\n";
+			} else {
+				print "<a name=\"unicode\">\n";
+			}
+
+			if ($cnt == 0) {    
+				print "<b><tt>$grep_str_html</tt> was not found</b><br>\n";
+			} elsif ($cnt == 1) {
+				print "<b>1 occurrence of <tt>$grep_str_html</tt> was found</b><br>\n";
+			} else {
+				print "<b>$cnt occurrences of <tt>$grep_str_html</tt> were found</b><br>\n";
+			}
+
+			print "Search Options:<br>\n";
+			if ($type == 0) {
+				print "&nbsp;&nbsp;ASCII<br>\n";
+			} else {
+				print "&nbsp;&nbsp;Unicode<br>\n";
+			}
+
+			if ($grep_flag =~ /\-i/) {
+				print "&nbsp;&nbsp;Case Insensitive<br>\n";
+			} else {
+				print "&nbsp;&nbsp;Case Sensitive<br>\n";
+			}
+			if ($grep_flag =~ /\-E/) {
+				print "&nbsp;&nbsp;Regular Expression<br>\n";
+			}
+
+			print "<hr>\n";
+
+			if ($cnt > 1000) {
+				print "There were more than <U>1000</U> hits.<br>\n";
+				print "Please revise the search to a managable amount.\n";
+				print "<p>The $cnt hits can be found in: <tt>$srch_name</tt><br>\n";
+				close (SRCH);
+				return 0;
+			}
+
+			next;
+		}
+
+
+		unless (/^(\d+)\|(\d+)\|(.*)?$/) {
+			print "Error parsing results: $_\n";
+			close (SRCH);
 			return 1;
 		}
 
@@ -704,7 +851,7 @@ sub print_srch_results {
 			$prev = $blk;
 		}
 
-		my $occ = $i + 1;
+		my $occ = $. - 1;
 		if ($str ne "")  {
 			$str = Print::html_encode($str);	
 			print "$occ: $off (<tt>$str</tt>)<br>\n";
@@ -713,6 +860,7 @@ sub print_srch_results {
 		}
 	}
 
+	close(SRCH);
 	return 0;
 };
 
