@@ -54,11 +54,6 @@ sub main {
     Args::check_view();    
     my $view = Args::get_view();
 
-    if ($view == $Meta::BLANK) {
-        blank();	
-        return 0;
-    }
-
 
     # Check Basic Args
     Args::check_img('img');
@@ -76,6 +71,9 @@ sub main {
     elsif ($view == $Meta::LIST) {
         return list();	
     }
+    elsif ($view == $Meta::BLANK) {
+        return blank();	
+    }
 
 
     
@@ -286,10 +284,10 @@ sub stats {
 
 	if ($recmode == $File::REC_YES) {
 		Exec::exec_pipe(*OUT, 
-		  "'$::TSKDIR/icat' -f $ftype -r '$img' $meta | '$::TSKDIR/file' -z -b -");
+		  "'$::TSKDIR/icat' -f $ftype -r '$img' $meta | '$::FILE_EXE' -z -b -");
 	} else {
 		Exec::exec_pipe(*OUT, 
-		  "'$::TSKDIR/icat' -f $ftype '$img' $meta | '$::TSKDIR/file' -z -b -");
+		  "'$::TSKDIR/icat' -f $ftype '$img' $meta | '$::FILE_EXE' -z -b -");
 	}
 	my $file_type = Exec::read_pipe_line(*OUT);
 	close (OUT);
@@ -358,6 +356,28 @@ sub stats {
 		  "</td></tr></table>\n</form>\n";
 	}
 
+	# SHA-1 Value
+	if ($recmode == $File::REC_YES) {
+		Exec::exec_pipe(*OUT, 
+		  "'$::TSKDIR/icat' -f $ftype -r '$img' $meta | '$::TSKDIR/sha1'");
+	} else {
+		Exec::exec_pipe(*OUT, 
+		  "'$::TSKDIR/icat' -f $ftype '$img' $meta | '$::TSKDIR/sha1'");
+	}
+
+	my $sha1out = Exec::read_pipe_line(*OUT);
+	close (OUT);
+
+	$sha1out = "Error getting SHA-1" 
+	  if ((!defined $sha1out) || ($sha1out eq ""));
+
+	chomp $sha1out;
+	if ($recmode == $File::REC_YES) {
+		print "<b>SHA-1 of recovered content:</b><br><tt>$sha1out</tt><br>\n";
+	} else {
+		print "<b>SHA-1 of content:</b><br><tt>$sha1out</tt><br>\n";
+	}
+
 
 	# istat output
 	print "<b>Details:</b><br>\n";
@@ -545,6 +565,17 @@ sub report {
 	chop $md5;
 	print "MD5 of istat output: $md5\n";
 
+
+	Exec::exec_pipe(*OUT, "'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts '$img' $meta | '$::TSKDIR/sha1'");
+	my $sha1 = Exec::read_pipe_line(*OUT);
+	close (OUT);
+
+	$sha1 = "Error getting SHA-1 Value"
+	  if ((!defined $sha1) || ($sha1 eq ""));
+
+	chop $sha1;
+	print "SHA-1 of istat output: $sha1\n";
+
 	print "\nImage: $img\n";
 	print "Image Type: $ftype\n";
 
@@ -563,10 +594,10 @@ sub report {
 
 	if ($recmode == $File::REC_YES) {
 		Exec::exec_pipe (*OUT,
-		  "'$::TSKDIR/icat' -f $ftype -r '$img' $meta | '$::TSKDIR/file' -z -b -");
+		  "'$::TSKDIR/icat' -f $ftype -r '$img' $meta | '$::FILE_EXE' -z -b -");
 	} else {
 		Exec::exec_pipe (*OUT,
-		  "'$::TSKDIR/icat' -f $ftype '$img' $meta | '$::TSKDIR/file' -z -b -");
+		  "'$::TSKDIR/icat' -f $ftype '$img' $meta | '$::FILE_EXE' -z -b -");
 	}
 
 	my $file_type = Exec::read_pipe_line(*OUT);
@@ -662,11 +693,18 @@ my $ILS_GAP = 500;
 
 };
 
+
 # Blank Page
-sub blank { 
-	Print::print_html_header("");
-	print "<!-- This Page Intentionally Left Blank -->\n";
+sub blank {
+	Print::print_html_header("Metadata Blank Page");
+	my $ftype = Args::get_ftype();
+
+	print "<center><h3>Metadata Mode</h3><br>\n".
+             "Here you can view the details about any $Fs::meta_str{$ftype} in the file system.<br>\n".
+	    "These are the data structures that store the file details.<br>\n".
+            "Enter the address in the field on the left.\n";
 	Print::print_html_footer();
 	return 0;
 };
 
+
