@@ -118,6 +118,7 @@ sub enter_file {
            "<center><b>Enter a note for $Fs::meta_str{$ftype} $meta:</b>".
           "<br><br>\n";
     }
+	print "A note works like a bookmark and allows you to later find this data more easily.<br><br>\n";
 
     # Setup the form
     print 
@@ -173,13 +174,14 @@ sub enter_file {
 
     # Print the Times
     print 
-      "<br><b>Add a Sequencer Event:</b><br>\n".
+      "<br><hr><b>Add a Sequencer Event:</b><br><br>\n".
+        "A sequencer event will be sorted based on the time so that event reconstruction will be easier<br><br>\n".
         "<input type=\"checkbox\" name=\"mtime\" value=\"1\">".
         "&nbsp;&nbsp;M-Time (<tt>$mtime</tt>)<br>\n".
         "<input type=\"checkbox\" name=\"atime\" value=\"1\">".
         "&nbsp;&nbsp;A-Time (<tt>$atime</tt>)<br>\n".
         "<input type=\"checkbox\" name=\"ctime\" value=\"1\">".
-        "&nbsp;&nbsp;C-Time (<tt>$ctime</tt>)<br>\n";
+        "&nbsp;&nbsp;C-Time (<tt>$ctime</tt>)<br><hr><br>\n";
 
     # The OK Button
     print 
@@ -205,6 +207,7 @@ sub enter_data {
 
     print 
       "<center><b>Enter a note for $Fs::addr_unit{$ftype} $block</b><br><br>\n".
+	"A note works like a bookmark and allows you to later find this data more easily.<br><br>\n".
       "<form action=\"$::PROGNAME\" method=\"get\">\n".
       "<textarea rows=10 cols=50 wrap=\"virtual\" name=\"note\">".
       "</textarea><br>\n".
@@ -232,6 +235,8 @@ sub write_data {
     Args::check_len();
     Args::check_note();
 
+	Print::print_html_header("Write a note");
+
     my $img_sh = Args::get_img_short('img');
     my $ftype = Args::get_ftype();
     my $block = Args::get_block();
@@ -241,26 +246,34 @@ sub write_data {
 
     my $notes_file = investig_notes_fname();
     open NOTES, ">>$notes_file" or die "Can't open log: $notes_file";
-    print "Note added to $notes_file:\n\n";
+    print "Note added to $notes_file:<p>\n\n";
 
     # Date
     my $tmp = localtime();
     print NOTES "$tmp\n";
-    print "$tmp\n";
+    print "$tmp<br>\n";
 
 
     print NOTES "Image: $img_sh  $Fs::addr_unit{$ftype}: $block  Len: $len\n";
-    print "Image: $img_sh  $Fs::addr_unit{$ftype}: $block  Len: $len\n";
+    print "Image: $img_sh  $Fs::addr_unit{$ftype}: $block  Len: $len<br>\n";
 
 
     # The actual notes and a line at the bottom
     print NOTES "\n$Args::args{'note'}\n\n".
           "-" x 62 ."\n";
-    print "\n$Args::args{'note'}\n\n";
+    print "<p>$Args::args{'note'}<p>";
 
     close (NOTES);
 
-    return 0;
+	print "<hr>\n".
+	  "You can view the notes from the Host Manager View<p>".
+	  "<a href=\"$::PROGNAME?${Args::baseargs_noimg}&mod=$::MOD_NOTES&view=$Notes::READ_NORM\">".
+	  "<img border=0 src=\"pict/menu_b_note.jpg\" ".
+	  "width=\"167\" height=20 alt=\"View Notes\"></a>\n";
+
+	Print::print_html_footer();
+
+	return 0;
 }
 
 
@@ -303,14 +316,14 @@ sub write_file {
     }
 
 
-    Print::print_text_header();
+    Print::print_html_header("Writing a note / event");
 
     # Create a "normal" note
     if ((exists $Args::args{'norm_note'}) && ($Args::args{'norm_note'} == 1)) {
 
         my $notes_file = investig_notes_fname();
         open NOTES, ">>$notes_file" or die "Can't open log: $notes_file";
-        print "Note added to $notes_file:\n\n";
+        print "Note added to $notes_file:<p>\n\n";
 
         # Date
         my $tmp = localtime();
@@ -321,33 +334,44 @@ sub write_file {
         if ($fname ne "") {
             if ($type eq 'dir') {
                 print NOTES "Directory: $fname\n";
-                print "Directory: $fname\n";
+                print "Directory: $fname<br>\n";
             }
             else {
                 print NOTES "File: $fname\n";
-                print "File: $fname\n";
+                print "File: $fname<br>\n";
             }
         }
         if ($meta ne "") {
             print NOTES "Image: $img_sh  Meta: $meta\n";
-            print "Image: $img_sh  Meta: $meta\n";
+            print "Image: $img_sh  Meta: $meta<br>\n";
         }
         
 
         # The actual notes and a line at the bottom
         print NOTES "\n$Args::args{'note'}\n\n".
           "-" x 62 ."\n";
-        print "\n$Args::args{'note'}\n\n";
+        print "<p>$Args::args{'note'}<p>";
+
 
         close (NOTES);
     }
 
 
     # Create a sequencer event - if there are any
-    return 0 
-      unless ( ((exists $Args::args{'mtime'}) && ($Args::args{'mtime'} == 1)) ||
+    unless ( ((exists $Args::args{'mtime'}) && ($Args::args{'mtime'} == 1)) ||
 	       ((exists $Args::args{'atime'}) && ($Args::args{'atime'} == 1)) ||
-	       ((exists $Args::args{'ctime'}) && ($Args::args{'ctime'} == 1)) );
+	       ((exists $Args::args{'ctime'}) && ($Args::args{'ctime'} == 1)) ) {
+
+		print "<hr>\n".
+		  "You can view the notes from the Host Manager View<p>".
+		  "<a href=\"$::PROGNAME?${Args::baseargs_noimg}&mod=$::MOD_NOTES&view=$Notes::READ_NORM\">".
+		  "<img border=0 src=\"pict/menu_b_note.jpg\" ".
+		  "width=\"167\" height=20 alt=\"View Notes\"></a>\n";
+
+		Print::print_html_footer();
+
+		return 0 
+    }
 
 
     my $img_path = Args::get_img('img');
@@ -400,7 +424,7 @@ sub write_file {
           "'$type','[M-Time]$Args::args{'note'}'\n";
 
         Print::log_host_inv ("$img_sh: M-Time note added for meta $Args::args{'meta'}");
-        print "M-Time sequence event added\n";
+        print "M-Time sequence event added<br>\n";
     }
     
     if ((exists $Args::args{'atime'}) && ($Args::args{'atime'} == 1)) {
@@ -417,7 +441,7 @@ sub write_file {
           "'$type','[A-Time]$Args::args{'note'}'\n";
 
         Print::log_host_inv ("$img_sh: A-Time note added for meta $Args::args{'meta'}");
-        print "A-Time sequence event added\n";
+        print "A-Time sequence event added<br>\n";
     }
     
     if ((exists $Args::args{'ctime'}) && ($Args::args{'ctime'} == 1)) {
@@ -434,14 +458,27 @@ sub write_file {
             "'$type','[C-Time]$Args::args{'note'}'\n";
 
         Print::log_host_inv ("$img_sh: C-Time note added for meta $Args::args{'meta'}");
-        print "C-Time sequence event added\n";
+        print "C-Time sequence event added<br>\n";
     }
 
     close (NOTES);
 
-	Print::print_text_footer();
+	print "<p><hr>\n".
+	    "You can view the notes and events from the Host Manager View<p>";
 
-    return 0;
+	if ((exists $Args::args{'norm_note'}) && ($Args::args{'norm_note'} == 1)) {
+		print "<a href=\"$::PROGNAME?${Args::baseargs_noimg}&mod=$::MOD_NOTES&view=$Notes::READ_NORM\">".
+		  "<img border=0 src=\"pict/menu_b_note.jpg\" ".
+		  "width=\"167\" height=20 alt=\"View Notes\"></a>\n";
+	}
+
+	print "<a href=\"$::PROGNAME?${Args::baseargs_noimg}&mod=$::MOD_NOTES&view=$Notes::READ_SEQ\">".
+	  "<img border=0 src=\"pict/menu_b_seq.jpg\" width=\"167\" height=\"20\" ".
+	  " alt=\"Event Sequencer\"></a>\n";
+
+	Print::print_html_footer();
+
+	return 0;
 };
 
 
@@ -454,7 +491,8 @@ sub read_norm {
 
 	Print::log_host_inv ("Viewing contents of notes file ($notes_file)");
 	if ((!(-e "$notes_file")) || (-z "$notes_file")) {
-		print "No notes have been entered yet<br>\n";
+		print "No notes have been entered yet.<br>\n".
+			"They can be entered using the <i>Add Note</i> link within each analysis mode.<br>\n";
 		return;
 	}
 
@@ -543,22 +581,23 @@ sub read_norm {
 
 	print "</tr></table>\n";
 
-    # Ok and refresh buttons    
-    print 
-      "<p><center><table width=600>\n".
-      "<tr><td width=300 align=center>\n".
-      "<a href=\"$::PROGNAME?mod=$::MOD_CASEMAN&".
-      "view=$Caseman::IMG_OPEN&$Args::baseargs\">".
-      "<img border=0 src=\"pict/menu_b_ok.jpg\" width=167 height=20></a>\n".
-      "</td><td width=300 align=center>\n".
-      "<a href=\"$::PROGNAME?mod=$::MOD_NOTES&view=$Notes::READ_NORM&$Args::baseargs\">".
-      "<img border=0 src=\"pict/menu_b_ref.jpg\" width=167 height=20></a>\n".
-      "</td></tr></table>\n";
+	# Ok and refresh buttons    
+	print 
+	  "<p><center><table width=600>\n".
+	  "<tr><td width=300 align=center>\n".
+	  "<a href=\"$::PROGNAME?mod=$::MOD_CASEMAN&".
+	  "view=$Caseman::IMG_OPEN&$Args::baseargs\">".
+	  "<img border=0 src=\"pict/menu_b_ok.jpg\" width=167 height=20></a>\n".
+	  "</td><td width=300 align=center>\n".
+	  "<a href=\"$::PROGNAME?mod=$::MOD_NOTES&view=$Notes::READ_NORM&$Args::baseargs\">".
+	  "<img border=0 src=\"pict/menu_b_ref.jpg\" width=167 height=20></a>\n".
+	  "</td></tr></table>\n";
 
-    close (NOTES);
+	close (NOTES);
 
 	Print::print_html_footer();
-    return 0;
+
+	return 0;
 };
 
 
