@@ -275,6 +275,7 @@ sub body_enter {
 	  "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_TL\">\n".
 	  "<input type=\"hidden\" name=\"view\" value=\"$Timeline::BODY_RUN\">\n".
 	  Args::make_hidden().
+	  "<p>Here  we will process the file system images, collect the temporal data, and save the data to a single file.".  
 	  "<p>1.  Select one or more of the following images to collect data from:\n".
 	  "<table cellspacing=\"8\" cellpadding=\"2\">";
 
@@ -489,7 +490,9 @@ sub body_run {
 		print "MD5 Value: <tt>$m</tt><br><br>\n";
 	}
 
-	print "<form action=\"$::PROGNAME\" method=\"get\" target=\"_top\">\n".
+	print 
+	  "<p>The next step is to sort the data into a timeline.".
+	  "<form action=\"$::PROGNAME\" method=\"get\" target=\"_top\">\n".
 	  "<input type=\"hidden\" name=\"body\" value=\"$Args::args{'fname'}\">\n".
 	  "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_TL\">\n".
 	  "<input type=\"hidden\" name=\"view\" value=\"$Timeline::FRAME\">\n".
@@ -528,7 +531,9 @@ sub tl_enter {
 			return 1;
 		}
 	}
-	print "<form action=\"$::PROGNAME\" method=\"get\">\n".
+	print 
+	  "Now we will sort the data and save it to a timeline.<p>\n". 
+	  "<form action=\"$::PROGNAME\" method=\"get\">\n".
 	  "<input type=\"hidden\" name=\"mod\" value=\"$::MOD_TL\">\n".
 	  "<input type=\"hidden\" name=\"view\" value=\"$Timeline::TL_RUN\">\n".
 	  Args::make_hidden().
@@ -543,11 +548,13 @@ sub tl_enter {
 	}
 	else {
 		my @body_sort = sort {lc($a) cmp lc($b)} @body;
+		my $chk = " CHECKED";
 		for (my $i = 0; $i <= $#body_sort; $i++) {
 			(my $img_dir, my $str_img) = split (/\//,$body_sort[$i]);
 
 			print "<tr><td><input type=\"radio\" name=\"body\" ".
-			  "value=\"$str_img\"></td><td>$str_img</td>\n";
+			  "value=\"$str_img\" $chk></td><td>$str_img</td>\n";
+			$chk = "";
 		}
 	}
 
@@ -610,7 +617,7 @@ sub tl_enter {
 
 	# FILE NAME
 	print "<p>4.   Enter the file name to save as:<br>".
-	  "<tt>$::DATADIR/</tt><input type=\"text\" size=36 name=\"fname\"><br>\n".
+	  "<tt>$::DATADIR/</tt><input type=\"text\" size=36 name=\"fname\" value=\"timeline.txt\"><br>\n".
 	  "<input type=\"hidden\" name=\"fname_mode\" value=\"$FNAME_MODE_INIT\">\n";
 
 
@@ -1273,7 +1280,12 @@ sub view {
 # Blank Page
 sub blank { 
 	Print::print_html_header("");
-	print "<!-- This Page Intentionally Left Blank -->\n";
+	print "<center><h3>File Activity Timelines</h3>\n".
+		"Here you can create a timeline of file activity.<br>\n".
+		"This process requires two steps:<p>\n".
+		"1.  <b>Create Data File</b> from file system data&nbsp;&nbsp;->".
+		"&nbsp;&nbsp;2.  <b>Create Timeline</b> from the data file\n".
+		"<p>Use the tabs above to start.\n";
 	Print::print_html_footer();
 	return 0;
 };
